@@ -107,7 +107,6 @@ gdm_session_list_from_hash_table_func (const char *key, const char *value,
         *sessions = g_list_prepend (*sessions, g_strdup (key));
 }
 
-
 void
 gdm_session_list_init ()
 {
@@ -125,6 +124,7 @@ gdm_session_list_init ()
     if (gdm_config_get_bool (GDM_KEY_SHOW_GNOME_FAILSAFE)) {
 	session = g_new0 (GdmSession, 1);
 	session->name = g_strdup (_("Failsafe _GNOME"));
+	session->clearname = g_strdup (_("Failsafe GNOME"));
 	session->comment = g_strdup (_("This is a failsafe session that will log you "
 		"into GNOME. No startup scripts will be read "
 		"and it is only to be used when you can't log "
@@ -134,8 +134,10 @@ gdm_session_list_init ()
     }
 
     if (gdm_config_get_bool (GDM_KEY_SHOW_XTERM_FAILSAFE)) {
+	/* Valgrind complains that the below is leaked */
 	session = g_new0 (GdmSession, 1);
 	session->name = g_strdup (_("Failsafe _Terminal"));
+	session->clearname = g_strdup (_("Failsafe Terminal"));
 	session->comment = g_strdup (_("This is a failsafe session that will log you "
 		"into a terminal.  No startup scripts will be read "
 		"and it is only to be used when you can't log "
@@ -192,7 +194,8 @@ gdm_session_list_init ()
 
 		    if (ve_config_get_bool (cfg, "Desktop Entry/Hidden=false")) {
 			    session = g_new0 (GdmSession, 1);
-			    session->name = "foo";
+			    session->name      = g_strdup (dent->d_name);
+			    session->clearname = NULL;
 			    g_hash_table_insert (sessnames, g_strdup (dent->d_name), session);
 			    ve_config_destroy (cfg);
 			    dent = readdir (sessdir);
@@ -201,10 +204,17 @@ gdm_session_list_init ()
 
 		    tryexec = ve_config_get_string (cfg, "Desktop Entry/TryExec");
 		    if ( ! ve_string_empty (tryexec)) {
-			    char *full = g_find_program_in_path (tryexec);
+			    char **tryexecvec = g_strsplit (tryexec, " ", -1);
+			    char *full = NULL;
+
+			    /* Do not pass any arguments to g_find_program_in_path */
+			    if (tryexecvec != NULL)
+				full = g_find_program_in_path (tryexecvec[0]);
+
 			    if (full == NULL) {
 				    session = g_new0 (GdmSession, 1);
-				    session->name = "foo";
+				    session->name      = g_strdup (dent->d_name);
+				    session->clearname = NULL;
 				    g_hash_table_insert (sessnames, g_strdup (dent->d_name),
 					 session);
 				    g_free (tryexec);
@@ -212,6 +222,7 @@ gdm_session_list_init ()
 				    dent = readdir (sessdir);
 				    continue;
 			    }
+			    g_strfreev (tryexecvec);
 			    g_free (full);
 		    }
 		    g_free (tryexec);
@@ -224,7 +235,8 @@ gdm_session_list_init ()
 
 		    if G_UNLIKELY (ve_string_empty (exec) || ve_string_empty (name)) {
 			    session = g_new0 (GdmSession, 1);
-			    session->name = "foo";
+			    session->name      = g_strdup (dent->d_name);
+			    session->clearname = NULL;
 			    g_hash_table_insert (sessnames, g_strdup (dent->d_name), session);
 			    g_free (exec);
 			    g_free (name);
@@ -258,8 +270,9 @@ gdm_session_list_init ()
 		    }
 
 		    session = g_new0 (GdmSession, 1);
-		    session->name = g_strdup (name);
-		    session->comment = g_strdup (comment);
+		    session->name      = g_strdup (name);
+		    session->clearname = NULL;
+		    session->comment   = g_strdup (comment);
 		    g_hash_table_insert (sessnames, g_strdup (dent->d_name), session);
 		    g_free (exec);
 		    g_free (comment);
@@ -290,9 +303,10 @@ gdm_session_list_init ()
 
 
     if (gdm_config_get_bool (GDM_KEY_SHOW_GNOME_FAILSAFE)) {
-	    session          = g_new0 (GdmSession, 1);
-	    session->name    = g_strdup (_("Failsafe _GNOME"));
-	    session->comment = g_strdup (_("This is a failsafe session that will log you "
+	    session            = g_new0 (GdmSession, 1);
+	    session->name      = g_strdup (_("Failsafe _GNOME"));
+	    session->clearname = g_strdup (_("Failsafe GNOME"));
+	    session->comment   = g_strdup (_("This is a failsafe session that will log you "
 				    "into GNOME. No startup scripts will be read "
                                     "and it is only to be used when you can't log "
                                     "in otherwise.  GNOME will use the 'Default' "
@@ -302,9 +316,10 @@ gdm_session_list_init ()
     }
 
     if (gdm_config_get_bool (GDM_KEY_SHOW_XTERM_FAILSAFE)) {
-	    session          = g_new0 (GdmSession, 1);
-	    session->name    = g_strdup (_("Failsafe _Terminal"));
-	    session->comment = g_strdup (_("This is a failsafe session that will log you "
+	    session            = g_new0 (GdmSession, 1);
+	    session->name      = g_strdup (_("Failsafe _Terminal"));
+	    session->clearname = g_strdup (_("Failsafe Terminal"));
+	    session->comment   = g_strdup (_("This is a failsafe session that will log you "
 				    "into a terminal.  No startup scripts will be read "
 				    "and it is only to be used when you can't log "
 				    "in otherwise.  To exit the terminal, "
